from zenlib.util import colorize, check_dict, handle_plural, pretty_print, replace_file_line, update_init, walk_dict
from zenlib.logging import ColorLognameFormatter, loggify
from zenlib.types import NoDupFlatList, validatedDataclass
from zenlib.namespace import nsexec

# Global setting for color logging
_ZENLIB_COLOR_TEXT = True

__all__ = [
    "colorize",
    "ColorLognameFormatter",
    "loggify",
    "handle_plural",
    "nsexec",
    "NoDupFlatList",
    "validatedDataclass",
    "pretty_print",
    "replace_file_line",
    "update_init",
    "walk_dict",
    "check_dict",
    "_ZENLIB_COLOR_TEXT",
]
